    "mcp-dnsdumpster": {
      "command": "uv",
      "args": [
        "--directory",
        "/Users/mweeden/dev/mcp/mcp-dnsdumpster",
        "run",
        "server.py"
      ],
      "env": {
        "DNSDUMPSTER_API_KEY": "f1fd75cda5169bb728006dda6218ab5d6c90fdc42450d51bc69e392a92459c7f"
      }
    }